==> bw-webdav-4.0.8-sources.jar: org/bedework/webdav/servlet/shared/WebdavForbidden.java <==
/* ********************************************************************
    Licensed to Jasig under one or more contributor license
    agreements. See the NOTICE file distributed with this work
    for additional information regarding copyright ownership.
    Jasig licenses this file to you under the Apache License,
    Version 2.0 (the "License"); you may not use this file
    except in compliance with the License. You may obtain a
    copy of the License at:

    http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing,
    software distributed under the License is distributed on
    an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, either express or implied. See the License for the
    specific language governing permissions and limitations
    under the License.
*/

package org.bedework.webdav.servlet.shared;

import javax.servlet.http.HttpServletResponse;
import javax.xml.namespace.QName;

/** Forbidden exception thrown by webdav classes
 *
 *   @author Mike Douglass   douglm  rpi.edu
 */
public class WebdavForbidden extends WebdavException {
  /** Constructor
   */
  public WebdavForbidden() {
    super(HttpServletResponse.SC_FORBIDDEN);
  }

  /** Constructor
   * @param msg
   */
  public WebdavForbidden(String msg) {
    super(HttpServletResponse.SC_FORBIDDEN, msg);
  }

  /** Constructor
   *
   * @param errorTag
   */
  public WebdavForbidden(QName errorTag) {
    super(HttpServletResponse.SC_FORBIDDEN, errorTag);
  }

  /** Constructor
   *
   * @param errorTag
   * @param msg
   */
  public WebdavForbidden(QName errorTag, String msg) {
    super(HttpServletResponse.SC_FORBIDDEN, errorTag, msg);
  }
}

==> bw-webdav-5.0.2-sources.jar: org/bedework/webdav/servlet/shared/WebdavForbidden.java <==
/* ********************************************************************
    Licensed to Jasig under one or more contributor license
    agreements. See the NOTICE file distributed with this work
    for additional information regarding copyright ownership.
    Jasig licenses this file to you under the Apache License,
    Version 2.0 (the "License"); you may not use this file
    except in compliance with the License. You may obtain a
    copy of the License at:

    http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing,
    software distributed under the License is distributed on
    an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, either express or implied. See the License for the
    specific language governing permissions and limitations
    under the License.
*/

package org.bedework.webdav.servlet.shared;

import javax.servlet.http.HttpServletResponse;
import javax.xml.namespace.QName;

/** Forbidden exception thrown by webdav classes
 *
 *   @author Mike Douglass   douglm  rpi.edu
 */
public class WebdavForbidden extends WebdavException {
  /** Constructor
   */
  public WebdavForbidden() {
    super(HttpServletResponse.SC_FORBIDDEN);
  }

  /** Constructor
   * @param msg text
   */
  public WebdavForbidden(final String msg) {
    super(HttpServletResponse.SC_FORBIDDEN, msg);
  }

  /** Constructor
   *
   * @param errorTag to label
   */
  public WebdavForbidden(final QName errorTag) {
    super(HttpServletResponse.SC_FORBIDDEN, errorTag);
  }

  /** Constructor
   *
   * @param errorTag to label
   */
  public WebdavForbidden(final Throwable t,
                         final QName errorTag) {
    super(t, HttpServletResponse.SC_FORBIDDEN, errorTag);
  }

  /** Constructor
   *
   * @param errorTag for label
   * @param msg test
   */
  public WebdavForbidden(final QName errorTag, final String msg) {
    super(HttpServletResponse.SC_FORBIDDEN, errorTag, msg);
  }
}
